@@ -378,6 +378,14 @@ The firewall helper APIs.
 
 The polkit authentication / authorization APIs
 
+=item Sys::Virt::Error::FROM_THREAD
+
+The thread helper utils
+
+=item Sys::Virt::Error::FROM_ADMIN
+
+The administrative service
+
 =back
 
 =head2 ERROR CODE CONSTANTS
